# OzNetNerd Deep Security

Convenience Python module for interacting with Trend Micro Deep Security

## Installation

```
pip3 install onnds
```

# Contact

* Blog: oznetnerd.com
* Email: will@oznetnerd.com